"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.processPackage = void 0;
const fs_1 = require("fs");
const promises_1 = __importDefault(require("fs/promises"));
const path_1 = __importDefault(require("path"));
const resolve_package_path_1 = __importDefault(require("resolve-package-path"));
const executor_1 = require("./executor");
const package_editor_1 = require("./package-editor");
const typescript_config_1 = require("./typescript-config");
const findPackagePath = (name) => {
    return path_1.default.dirname((0, resolve_package_path_1.default)(name, __dirname) || require.resolve(name));
};
const processPackage = async (name, { include = ['./**/*.js'], exclude = ['./**/*.d.ts'] }) => {
    const location = findPackagePath(name);
    const tsconfigPath = path_1.default.join(location, typescript_config_1.TsconfigName);
    const createTsConfig = !(0, fs_1.existsSync)(tsconfigPath);
    if (createTsConfig) {
        await promises_1.default.writeFile(tsconfigPath, JSON.stringify((0, typescript_config_1.generateTsConfig)({ include, exclude })));
    }
    const command = (0, executor_1.generateCommand)(createTsConfig);
    const [, error] = await (0, executor_1.executeCommand)(command, { cwd: location });
    if (error) {
        console.error(error.err);
        return;
    }
    await (0, package_editor_1.editPackageJson)(location, (atual) => {
        const main = atual.main?.replace(/js$/, 'd.ts') || 'index.d.ts';
        const typesFolder = path_1.default.join('.', typescript_config_1.defaultCompilerOptions.outDir, main);
        return { ...atual, types: typesFolder };
    });
};
exports.processPackage = processPackage;
//# sourceMappingURL=process.js.map